# quetzal-CRUMBS
Geneal utility scripts for Quetzal projects

## Dependencies

### GDAL/OGR for Python:

- [Ubuntu installation](https://mothergeo-py.readthedocs.io/en/latest/development/how-to/gdal-ubuntu-pkg.html)
